==> openvdb-12.1.0-2-x86_64.pkg.tar.zst: usr/share/doc/OpenVDB/html/PoissonSolver_8h.js <==
var PoissonSolver_8h =
[
    [ "DirichletBoundaryOp< ValueType >", "structopenvdb_1_1v12__1_1_1tools_1_1poisson_1_1DirichletBoundaryOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1poisson_1_1DirichletBoundaryOp" ],
    [ "openvdb::v12_1::tools::poisson::LaplacianMatrix", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#aa0f700b7e93a8fc04d49928e5350b488", null ],
    [ "openvdb::v12_1::tools::poisson::VIndex", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a6610683e8f33cef4b298fd92d1e7306f", null ],
    [ "openvdb::v12_1::tools::poisson::createIndexTree", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a84c81c332ed27260f4cefebebe118786", null ],
    [ "openvdb::v12_1::tools::poisson::createISLaplacian", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a54eb0709abc6cd6d64f8d9685297d9d3", null ],
    [ "openvdb::v12_1::tools::poisson::createISLaplacianWithBoundaryConditions", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a11228470b0c119b061330893dcf4d84a", null ],
    [ "openvdb::v12_1::tools::poisson::createTreeFromVector", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#ad247afd9be5bc45c0ef563dfdcf9f521", null ],
    [ "openvdb::v12_1::tools::poisson::createVectorFromTree", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#aaafc8a2a26f1f3f386afd16268b8c19b", null ],
    [ "openvdb::v12_1::tools::poisson::populateIndexTree", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a28bc96576c35b652d14262997693ef21", null ],
    [ "openvdb::v12_1::tools::poisson::solve", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#ae79d948d2102c9bb9a687c8652b6086d", null ],
    [ "openvdb::v12_1::tools::poisson::solve", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a21ab8bffe12c0fdd360cc0fdff53f042", null ],
    [ "openvdb::v12_1::tools::poisson::solveWithBoundaryConditions", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a160805a9c45ca3b4150ff5b29da0d1aa", null ],
    [ "openvdb::v12_1::tools::poisson::solveWithBoundaryConditionsAndPreconditioner", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#af53fd5faf087f9dc41fac411fb256ad4", null ],
    [ "openvdb::v12_1::tools::poisson::solveWithBoundaryConditionsAndPreconditioner", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#aa31211523f1978176daa0219796b87ec", null ]
];

==> openvdb-12.1.1-3-x86_64.pkg.tar.zst: usr/share/doc/OpenVDB/html/PoissonSolver_8h.js <==
var PoissonSolver_8h =
[
    [ "DirichletBoundaryOp&lt; ValueType &gt;", "structopenvdb_1_1v12__1_1_1tools_1_1poisson_1_1DirichletBoundaryOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1poisson_1_1DirichletBoundaryOp" ],
    [ "openvdb::v12_1::tools::poisson::LaplacianMatrix", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#aa0f700b7e93a8fc04d49928e5350b488", null ],
    [ "openvdb::v12_1::tools::poisson::VIndex", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a6610683e8f33cef4b298fd92d1e7306f", null ],
    [ "openvdb::v12_1::tools::poisson::createIndexTree", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a84c81c332ed27260f4cefebebe118786", null ],
    [ "openvdb::v12_1::tools::poisson::createISLaplacian", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a54eb0709abc6cd6d64f8d9685297d9d3", null ],
    [ "openvdb::v12_1::tools::poisson::createISLaplacianWithBoundaryConditions", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a11228470b0c119b061330893dcf4d84a", null ],
    [ "openvdb::v12_1::tools::poisson::createTreeFromVector", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#ad247afd9be5bc45c0ef563dfdcf9f521", null ],
    [ "openvdb::v12_1::tools::poisson::createVectorFromTree", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#aaafc8a2a26f1f3f386afd16268b8c19b", null ],
    [ "openvdb::v12_1::tools::poisson::populateIndexTree", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a28bc96576c35b652d14262997693ef21", null ],
    [ "openvdb::v12_1::tools::poisson::solve", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#ae79d948d2102c9bb9a687c8652b6086d", null ],
    [ "openvdb::v12_1::tools::poisson::solve", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a21ab8bffe12c0fdd360cc0fdff53f042", null ],
    [ "openvdb::v12_1::tools::poisson::solveWithBoundaryConditions", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a160805a9c45ca3b4150ff5b29da0d1aa", null ],
    [ "openvdb::v12_1::tools::poisson::solveWithBoundaryConditionsAndPreconditioner", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#af53fd5faf087f9dc41fac411fb256ad4", null ],
    [ "openvdb::v12_1::tools::poisson::solveWithBoundaryConditionsAndPreconditioner", "namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#aa31211523f1978176daa0219796b87ec", null ]
];
